==> rocketmq-client-3.1.2-sources.jar: com/alibaba/rocketmq/client/impl/consumer/MQConsumerInner.java <==
/**
 * Copyright (C) 2010-2013 Alibaba Group Holding Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.rocketmq.client.impl.consumer;

import java.util.Set;

import com.alibaba.rocketmq.common.consumer.ConsumeFromWhere;
import com.alibaba.rocketmq.common.message.MessageQueue;
import com.alibaba.rocketmq.common.protocol.heartbeat.ConsumeType;
import com.alibaba.rocketmq.common.protocol.heartbeat.MessageModel;
import com.alibaba.rocketmq.common.protocol.heartbeat.SubscriptionData;


/**
 * Consumer内部接口，供MQClientFactory使用
 * 
 * @author shijia.wxr<vintage.wang@gmail.com>
 * @since 2013-7-24
 */
public interface MQConsumerInner {
    public String groupName();


    public MessageModel messageModel();


    public ConsumeType consumeType();


    public ConsumeFromWhere consumeFromWhere();


    public Set<SubscriptionData> subscriptions();


    public void doRebalance();


    public void persistConsumerOffset();


    public void updateTopicSubscribeInfo(final String topic, final Set<MessageQueue> info);


    public boolean isSubscribeTopicNeedUpdate(final String topic);


    public boolean isUnitMode();
}

==> rocketmq-client-3.1.8-sources.jar: com/alibaba/rocketmq/client/impl/consumer/MQConsumerInner.java <==
/**
 * Copyright (C) 2010-2013 Alibaba Group Holding Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.rocketmq.client.impl.consumer;

import java.util.Set;

import com.alibaba.rocketmq.common.consumer.ConsumeFromWhere;
import com.alibaba.rocketmq.common.message.MessageQueue;
import com.alibaba.rocketmq.common.protocol.body.ConsumerRunningInfo;
import com.alibaba.rocketmq.common.protocol.heartbeat.ConsumeType;
import com.alibaba.rocketmq.common.protocol.heartbeat.MessageModel;
import com.alibaba.rocketmq.common.protocol.heartbeat.SubscriptionData;


/**
 * Consumer内部接口，供MQClientFactory使用
 * 
 * @author shijia.wxr<vintage.wang@gmail.com>
 * @since 2013-7-24
 */
public interface MQConsumerInner {
    public String groupName();


    public MessageModel messageModel();


    public ConsumeType consumeType();


    public ConsumeFromWhere consumeFromWhere();


    public Set<SubscriptionData> subscriptions();


    public void doRebalance();


    public void persistConsumerOffset();


    public void updateTopicSubscribeInfo(final String topic, final Set<MessageQueue> info);


    public boolean isSubscribeTopicNeedUpdate(final String topic);


    public boolean isUnitMode();


    public ConsumerRunningInfo consumerRunningInfo();
}
